<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Models\AdminStaff;
use App\Http\Controllers\Controller;

class AdminStaffController extends Controller
{
    // Show all staff members
    public function index()
    {
        $pageTitle = 'Manage Staff';
         $staffs = AdminStaff::paginate(10);
        return view('admin.staff.index', compact('pageTitle', 'staffs'));
    }

    // Show create staff form
    public function create()
    {
        $pageTitle = 'Add Staff';
        return view('admin.staff.create', compact('pageTitle'));
    }

    // Store new staff
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:admin_staffs',
            'password' => 'required|min:6|confirmed',
        ]);

        AdminStaff::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password),
        ]);

        return redirect()->route('admin.staff.index')->with('success', 'Staff added successfully.');
    }

    // Edit staff details
    public function edit($id)
    {
        $staff = AdminStaff::findOrFail($id);
        $pageTitle = 'Edit Staff';
        return view('admin.staff.edit', compact('staff', 'pageTitle'));
    }

    // Update staff
    public function update(Request $request, $id)
    {
        $staff = AdminStaff::findOrFail($id);

        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:admin_staffs,email,'.$id,
        ]);

        $staff->update([
            'name' => $request->name,
            'email' => $request->email,
        ]);

        return redirect()->route('admin.staff.index')->with('success', 'Staff updated successfully.');
    }

    // Delete staff
    public function destroy($id)
    {
        AdminStaff::findOrFail($id)->delete();
        return redirect()->route('admin.staff.index')->with('success', 'Staff deleted successfully.');
    }
}
