<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Plan;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;

class PlanController extends Controller
{
    public function plan()
    {
        $pageTitle = 'Plans';
        $plans = Plan::orderBy('price', 'asc')->paginate(10);
        return view('admin.plan.index', compact('pageTitle', 'plans'));
    }

    public function planSave(Request $request)
    {
        // Validate input
        $request->validate([
            'name'                      => 'required|string|max:255|unique:plans,name,' . $request->id,
            'price'                     => 'required|numeric|min:0',
            'bv'                        => 'required|integer|min:0',
            'ref_com'                   => 'required|numeric|min:0',
            'max_pairs_amount'          => 'required|numeric|min:0', // Amount per pair
            'max_pairs_count'           => 'required|integer|min:0', // Number of pairs per day
            'infinite_pairs'            => 'required|numeric|min:0', // Unlimited earning amount
            'product_share_limit'       => 'required|integer|min:0',
            'product_share_commission'  => 'required|numeric|min:0',
            'plan_picture'              => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048'
        ]);

        // Find plan if ID exists, otherwise create a new plan
        $plan = $request->id ? Plan::findOrFail($request->id) : new Plan();

        // Assign values
        $plan->name                     = $request->name;
        $plan->price                    = $request->price;
        $plan->bv                        = $request->bv;
        $plan->ref_com                   = $request->ref_com;
        $plan->max_pairs_amount          = $request->max_pairs_amount; // Amount per pair
        $plan->max_pairs_count           = $request->max_pairs_count; // Number of pairs per day
        $plan->infinite_pairs            = $request->infinite_pairs; // Unlimited earning amount
        $plan->product_share_limit       = $request->product_share_limit;
        $plan->product_share_commission  = $request->product_share_commission;

        // Handle Plan Picture Upload
        if ($request->hasFile('plan_picture')) {
            // Delete the old image if it exists
            if ($plan->plan_picture && File::exists(public_path('assets/images/plan/' . $plan->plan_picture))) {
                File::delete(public_path('assets/images/plan/' . $plan->plan_picture));
            }

            $file = $request->file('plan_picture');
            $fileName = time() . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('assets/images/plan/'), $fileName);
            $plan->plan_picture = $fileName;
        }

        $plan->save();

        // Notify and redirect
        return back()->with(['success' => 'Plan saved successfully']);
    }

    public function status($id)
    {
        $plan = Plan::findOrFail($id);
        $plan->status = !$plan->status;
        $plan->save();

        return back()->with(['success' => 'Plan status updated successfully']);
    }
}
