<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Product;
use Illuminate\Support\Facades\Storage;

class ProductController extends Controller
{
    // Show all products
    public function index()
    {
        $products = Product::latest()->paginate(10);
        return view('admin.products.index', compact('products'));
    }

    // Show create form
    public function create()
    {
        return view('admin.products.create');
    }

    // Store new product

     public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'sku' => 'required|string|max:255',
            'stock' => 'required|integer',
            'price' => 'required|numeric',
            'discount' => 'nullable|numeric',
            'bv' => 'nullable|numeric',
            'short_description' => 'nullable|string',
            'description' => 'nullable|string',  // ✅ Make sure this exists
            'image' => 'nullable|image|max:2048',
        ]);
    
        $product = new Product();
        $product->name = $request->input('name');
        $product->sku = $request->input('sku');
        $product->stock = $request->input('stock');
        $product->price = $request->input('price');
        $product->discount = $request->input('discount');
        $product->bv = $request->input('bv');
        $product->short_description = $request->input('short_description');
        $product->description = $request->input('description');  // ✅ Ensure this is saved
    
        if ($request->hasFile('image')) {
            $product->image = $request->file('image')->store('products', 'public');
        }
    
        $product->save();
    
        return redirect()->route('admin.products.index')->with('success', 'Product added successfully.');
    }


    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'sku' => 'required|string|max:255',
            'stock' => 'required|integer',
            'price' => 'required|numeric',
            'discount' => 'nullable|numeric',
            'bv' => 'nullable|numeric',
            'short_description' => 'nullable|string',
            'description' => 'nullable|string',
            'image' => 'nullable|image|max:2048',
        ]);

        $product = Product::findOrFail($id);
        $product->name = $request->input('name');
        $product->sku = $request->input('sku');
        $product->stock = $request->input('stock');
        $product->price = $request->input('price');
        $product->discount = $request->input('discount');
        $product->bv = $request->input('bv');
        $product->short_description = $request->input('short_description');
        $product->description = $request->input('description');

        if ($request->hasFile('image')) {
            $product->image = $request->file('image')->store('products', 'public');
        }

        $product->save();

        return redirect()->route('admin.products.index')->with('success', 'Product updated successfully.');
    }

    // Delete product
    public function destroy($id)
    {
        $product = Product::findOrFail($id);

        // Delete image if exists
        if ($product->image) {
            Storage::disk('public')->delete($product->image);
        }

        $product->delete();
        return redirect()->route('admin.products.index')->with('success', 'Product deleted successfully.');
    }
}
