<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class SettingController extends Controller
{
    /**
     * Show House Fund Wallet Settings Page.
     */
    public function houseFundWalletSettings()
    {
        $pageTitle = 'House Fund Wallet Settings';

        $settings = [
            'minimum_balance' => DB::table('settings')->where('key', 'house_fund_wallet_minimum_balance')->value('value') ?? 1000,
            'monthly_contribution' => DB::table('settings')->where('key', 'house_fund_wallet_monthly_contribution')->value('value') ?? 50,
        ];

        return view('admin.settings.house_fund_wallet', compact('pageTitle', 'settings'));
    }

    /**
     * Update House Fund Wallet Settings.
     */
    public function updateHouseFundWalletSettings(Request $request)
    {
        $request->validate([
            'minimum_balance' => 'required|numeric|min:1',
            'monthly_contribution' => 'required|numeric|min:1',
        ]);

        DB::table('settings')->updateOrInsert(
            ['key' => 'house_fund_wallet_minimum_balance'],
            ['value' => $request->minimum_balance]
        );

        DB::table('settings')->updateOrInsert(
            ['key' => 'house_fund_wallet_monthly_contribution'],
            ['value' => $request->monthly_contribution]
        );

        return back()->with('success', 'House Fund Wallet settings updated successfully.');
    }

    /**
     * Show Binary Commission Settings Page.
     */
    public function binaryCommissionSettings()
    {
        $pageTitle = 'Binary Commission Settings';

        $settings = [
            'minimum_purchase' => DB::table('settings')->where('key', 'binary_commission_minimum_purchase')->value('value') ?? 50,
            'generation_rates' => json_decode(DB::table('settings')->where('key', 'binary_commission_rates')->value('value'), true),
        ];

        return view('admin.settings.binary_commission', compact('pageTitle', 'settings'));
    }

    /**
     * Update Binary Commission Settings.
     */
    public function updateBinaryCommissionSettings(Request $request)
    {
        $request->validate([
            'minimum_purchase' => 'required|numeric|min:1',
            'generation_rates' => 'required|array',
        ]);

        DB::table('settings')->updateOrInsert(
            ['key' => 'binary_commission_minimum_purchase'],
            ['value' => $request->minimum_purchase]
        );

        DB::table('settings')->updateOrInsert(
            ['key' => 'binary_commission_rates'],
            ['value' => json_encode($request->generation_rates)]
        );

        return back()->with('success', 'Binary Commission settings updated successfully.');
    }
}
