<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\ShippingMethod;
use App\Models\Order;
use Illuminate\Http\Request;

class ShippingController extends Controller
{
    /**
     * Show all shipping methods
     */
    public function index()
    {
        $pageTitle = 'Manage Shipping Methods';
        $shippingMethods = ShippingMethod::all();
        return view('admin.shipping.index', compact('pageTitle', 'shippingMethods'));
    }

    /**
     * Store a new shipping method
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'cost' => 'required|numeric|min:0',
            'status' => 'required|boolean'
        ]);

        ShippingMethod::create([
            'name' => $request->name,
            'cost' => $request->cost,
            'status' => $request->status
        ]);

        return back()->with('success', 'Shipping method added successfully.');
    }

    /**
     * Update shipping method
     */
    public function update(Request $request, $id)
    {
        $shipping = ShippingMethod::findOrFail($id);
        $shipping->update([
            'name' => $request->name,
            'cost' => $request->cost,
            'status' => $request->status
        ]);

        return back()->with('success', 'Shipping method updated successfully.');
    }

    /**
     * Assign Tracking Number
     */
    public function updateTracking(Request $request, $id)
    {
        $request->validate(['tracking_number' => 'required|string|unique:orders']);
        $order = Order::findOrFail($id);
        $order->tracking_number = $request->tracking_number;
        $order->status = 'shipped';
        $order->save();

        notify($order->user, 'ORDER_TRACKING_UPDATE', [
            'order_id' => $order->id,
            'tracking_number' => $order->tracking_number
        ]);

        return back()->with('success', 'Tracking number updated.');
    }
}
