<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\User; 
use App\Models\Stockiest;
use Illuminate\Http\Request;

class StockiestController extends Controller
{
    public function index()
    {
        $stockiests = Stockiest::all();
        $userIds = Stockiest::whereNotNull('user_id')->pluck('user_id')->toArray();
        $users = User::whereNotIn('id', $userIds)->get();
        
        return view('admin.stockiest.index', compact('stockiests', 'users'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:stockiests,email',
            'phone' => 'required|string|max:20|unique:stockiests,phone',
            'location' => 'required|string|max:255',
            'user_id' => 'nullable|exists:users,id',
        ]);
    
        Stockiest::create([
            'name' => $request->name,
            'email' => $request->email,
            'phone' => $request->phone,
            'location' => $request->location,
            'status' => 1,
            'user_id' => $request->user_id ?? null,
        ]);
    
        return response()->json(['success' => true, 'message' => 'Stockiest added successfully!']);
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|unique:stockiests,email,' . $id,
            'phone' => 'required|string|max:20|unique:stockiests,phone,' . $id,
            'location' => 'required|string|max:255',
            'status' => 'required|boolean',
        ]);
    
        $stockiest = Stockiest::findOrFail($id);
        $stockiest->update($request->all());
    
        return response()->json(['success' => true, 'message' => 'Stockiest updated successfully!']);
    }

    public function delete(Request $request)
    {
        Stockiest::findOrFail($request->id)->delete();
        return response()->json(['success' => true, 'message' => 'Stockiest deleted successfully']);
    }
}
