<?php

namespace App\Http\Controllers;

use App\Models\AffiliateClick;
use App\Models\AffiliateCommission;
use App\Models\Product;
use App\Models\User;
use App\Models\Order;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AffiliateController extends Controller
{
    /**
     * Generate an affiliate link for a product.
     */
    public function generateLink($productId)
    {
        $user = Auth::user();
        $affiliateLink = url("/product/$productId?ref=" . $user->id);
        return response()->json(['link' => $affiliateLink]);
    }

    /**
     * Track Affiliate Clicks
     */
    public function trackClick(Request $request)
    {
        if ($request->has('ref')) {
            $referrer = User::find($request->ref);
            if ($referrer) {
                AffiliateClick::create([
                    'referrer_id' => $referrer->id,
                    'product_id' => $request->product_id,
                    'ip_address' => request()->ip(),
                ]);
            }
        }
        return redirect()->route('product.details', $request->product_id);
    }

    /**
     * Assign commissions when an order is completed
     */
    public function assignCommission($orderId)
    {
        $order = Order::findOrFail($orderId);

        // If the order was referred by an affiliate
        if ($order->referrer_id) {
            $referrer = User::find($order->referrer_id);
            if ($referrer) {
                $commissionPercentage = $referrer->plan->affiliate_commission ?? 2; // Default 2%
                $commissionAmount = ($order->total_price * $commissionPercentage) / 100;

                AffiliateCommission::create([
                    'user_id' => $referrer->id,
                    'order_id' => $order->id,
                    'amount' => $commissionAmount,
                ]);

                // Update referrer's balance
                $referrer->increment('balance', $commissionAmount);
            }
        }
    }
}
