<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class CartController extends Controller
{
    // ✅ Update Cart Item Quantity
    public function update(Request $request, $id)
    {
        $cart = session()->get('cart', []);

        if (!isset($cart[$id])) {
            return back()->with('error', 'Item not found in cart.');
        }

        $cart[$id]['quantity'] = max(1, $request->quantity); // Ensure at least 1 quantity
        session()->put('cart', $cart);

        return back()->with('success', 'Cart updated successfully!');
    }

    // ✅ Remove a Specific Item from Cart
    public function remove($id)
    {
        $cart = session()->get('cart', []);

        if (!isset($cart[$id])) {
            return back()->with('error', 'Item not found in cart.');
        }

        unset($cart[$id]);
        session()->put('cart', $cart);

        return back()->with('success', 'Item removed from cart.');
    }

    // ✅ Clear the Entire Cart
    public function clear()
    {
        session()->forget('cart');

        return back()->with('success', 'Cart cleared successfully.');
    }
}
