<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Product;
use App\Models\ShareLink;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Http;

class ShareController extends Controller
{
    public function generate(Request $request, $productId)
    {
        $user = auth()->user();

        $existing = ShareLink::where('user_id', $user->id)
                    ->where('product_id', $productId)
                    ->first();

        if ($existing) {
            // Redirect back if not an API call
            if (!$request->expectsJson()) {
                return redirect()->back()->with('success', 'Link already exists');
            }

            return response()->json([
                'status' => 'success',
                'message' => 'Link already exists',
                'link' => $existing->url
            ]);
        }

        $code = Str::random(10);

        $link = ShareLink::create([
            'user_id' => $user->id,
            'product_id' => $productId,
            'code' => $code,
        ]);

        // ✅ Append URL and save
        $link->url = route('share.track', ['code' => $code]);
        $link->save();

        if (!$request->expectsJson()) {
            return redirect()->back()->with('success', 'Link generated successfully');
        }

        return response()->json([
            'status' => 'success',
            'message' => 'Link generated successfully',
            'link' => $link->url
        ]);
    }

    public function track($code)
    {
        $link = ShareLink::where('code', $code)->firstOrFail();

        // Record basic analytics (IP, location, referrer, etc.)
        $link->increment('clicks');
        $link->last_clicked_at = now();
        $link->save();

        // 🔍 IP Geolocation via ipstack
        $ip = request()->ip();
        $response = Http::get("http://api.ipstack.com/{$ip}?access_key=34a11e9e79b6ccf36ab834d17e274cd6");
        $data = $response->json();

        $country = $data['country_name'] ?? 'Unknown';
        $city = $data['city'] ?? null;

        // 🧠 Log click details
        $link->clicks()->create([
            'ip_address' => $ip,
            'referrer' => request()->header('referer'),
            'country' => $country,
            'city' => $city,
            'clicked_at' => now(),
        ]);

        // 🔁 Redirect to the product page
        return redirect()->route('store.product', $link->product_id);
    }
}
