<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Order;
use Illuminate\Support\Facades\Auth;
use Barryvdh\DomPDF\Facade\Pdf;

class UserOrderController extends Controller
{
    // Display order history and tracking
    public function index(Request $request)
    {
        $user = Auth::user();

        $trackingOrder = null;
        if ($request->has('tracking_code')) {
            $trackingOrder = Order::where('tracking_code', $request->tracking_code)->first();
        }

        $orders = Order::where('user_id', $user->id)->latest()->paginate(10);
        
        $pageTitle = 'My Orders';
        return view('templates.basic.user.orders', compact('orders', 'trackingOrder', 'pageTitle'));
    }

    // Optional: View single order
    public function show($id)
    {
        $user = Auth::user();
        $order = Order::where('user_id', $user->id)->where('id', $id)->firstOrFail();

        return view('user.order-details', compact('order'));
    }
    
    public function invoice($id)
    {
        $order = Order::where('id', $id)
            ->where('user_id', auth()->id())
            ->with('items.product', 'shipping')
            ->firstOrFail();
    
        return view('templates.basic.user.invoice', compact('order'));
    }
    
    public function downloadInvoice($id)
    {
        $user = Auth::user();
        $order = Order::where('user_id', $user->id)->with('items.product', 'shipping')->findOrFail($id);
    
        $pdf = Pdf::loadView('user.invoice', compact('order'));
        return $pdf->download("Invoice-{$order->tracking_code}.pdf");
    }
}
