<?php

namespace App\Services;

use App\Models\User;
use App\Models\Commission;
use Carbon\Carbon;
use Illuminate\Support\Facades\Log;

class CommissionService
{

public function processCommission($userId, $amount, $generation = 1)
{
    Log::info("🔄 CommissionService: Processing commission for User ID: $userId, Generation: $generation, Amount: $amount");

    if ($generation > 10) {
        Log::warning("❌ Generation limit exceeded.");
        return;
    }

    $user = User::find($userId);
    if (!$user) {
        Log::error("❌ User ID: $userId not found!");
        return;
    }

    if ($this->isEligibleForCommission($user)) {
        $commissionPercentage = $this->getCommissionRate($generation);
        $commissionAmount = ($amount * $commissionPercentage) / 100;

        Log::info("✅ Creating commission: $commissionAmount for User ID: $userId, Generation: $generation");

        \App\Models\Commission::create([
            'user_id' => $user->id,
            'amount' => $commissionAmount,
            'generation' => $generation
        ]);
    } else {
        Log::warning("❌ User ID: $userId is not eligible. Checking next upline.");
        $nextUpline = $user->upline; // Assuming `upline` is a relationship in User model
        if ($nextUpline) {
            $this->processCommission($nextUpline->id, $amount, $generation);
        }
    }
}

    private function isEligibleForCommission($user)
    {
        return $user->last_purchase_date >= Carbon::now()->startOfMonth();
    }

    private function getCommissionRate($generation)
    {
        $rates = [1 => 10, 2 => 8, 3 => 6, 4 => 5, 5 => 4, 6 => 3, 7 => 2, 8 => 2, 9 => 1, 10 => 1];
        return $rates[$generation] ?? 0;
    }
}
