<?php

namespace App\Services;

use App\Models\User;
use App\Models\Commission;
use Carbon\Carbon;

class TreeCommissionService
{
    public function processCommission($userId, $amount, $generation = 1)
    {
        if ($generation > 10) {
            return; // Stop at Generation 10
        }

        $user = User::find($userId);

        if (!$user) {
            return; // User not found
        }

        // Check if user has made at least one purchase this month
        $isEligible = $user->last_purchase_date >= Carbon::now()->startOfMonth();

        if ($isEligible) {
            // Calculate Commission Percentage Based on Generation
            $commissionPercentage = $this->getCommissionRate($generation);
            $commissionAmount = ($amount * $commissionPercentage) / 100;

            // Save Commission to Database
            Commission::create([
                'user_id' => $user->id,
                'amount' => $commissionAmount,
                'generation' => $generation
            ]);
        } else {
            // Compression: Pass commission to the next eligible user
            $nextUpline = $user->upline; // Assuming `upline` is a relationship in the User model
            if ($nextUpline) {
                $this->processCommission($nextUpline->id, $amount, $generation);
            }
        }
    }

    private function getCommissionRate($generation)
    {
        $rates = [
            1 => 10, // 10% for Gen 1
            2 => 8,  // 8% for Gen 2
            3 => 6,  // 6% for Gen 3
            4 => 5,  // ...
            5 => 4,
            6 => 3,
            7 => 2,
            8 => 2,
            9 => 1,
            10 => 1
        ];
        return $rates[$generation] ?? 0; // Default to 0% if generation is out of bounds
    }
}
