@extends('admin.layouts.app')

@section('panel')
<div class="container-fluid px-3">
    <div class="card">
        <div class="card-header bg-primary text-white">
            <h5 class="mb-0">@lang('Affiliate Overview')</h5>
        </div>

        <div class="card-body table-responsive">
            <table class="table table-bordered table-striped align-middle w-100" id="adminAffiliateTable" style="min-width: 1400px;">
                <thead class="table-blue">
                    <tr>
                        <th>@lang('User')</th>
                        <th>@lang('Email')</th>
                        <th>@lang('Product')</th>
                        <th>@lang('Share Link')</th>
                        <th>@lang('Clicks')</th>
                        <th>@lang('Last Click')</th>
                        <th>@lang('Location')</th>
                        <th>@lang('Referrer')</th>
                        <th>@lang('Actions')</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($shareLinks as $link)
                        @php
                            $user = $link->user;
                            $product = $link->product;
                            $lastClick = $link->clicks()->latest()->first();
                            $shareUrl = $link->url ?? route('share.track', ['code' => $link->code]);
                        @endphp
                        <tr>
                            <td>{{ $user->fullname ?? $user->username }}</td>
                            <td>{{ $user->email }}</td>
                            <td>{{ $product->name }}</td>
                            <td>
                                <input type="text" class="d-none" id="link-{{ $link->id }}" value="{{ $shareUrl }}">
                                <button class="btn btn-sm btn-outline-primary copy-btn" data-target="link-{{ $link->id }}">
                                    @lang('Copy')
                                </button>
                            </td>
                            <td>{{ $link->clicks }}</td>
                            <td>{{ optional($link->last_clicked_at)->diffForHumans() ?? 'N/A' }}</td>
                            <td>{{ optional($lastClick)->country ?? 'N/A' }}{{ optional($lastClick)->city ? ', ' . $lastClick->city : '' }}</td>
                            <td>{{ $lastClick->referrer ?? 'N/A' }}</td>
                            <td>
                                <a href="{{ $shareUrl }}" class="btn btn-sm btn-success" target="_blank">
                                    <i class="fas fa-external-link-alt"></i>
                                </a>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
    </div>
</div>
@endsection

@push('script')
<script src="https://cdn.datatables.net/1.13.5/js/jquery.dataTables.min.js"></script>
<script>
    $(document).ready(function () {
        $('#adminAffiliateTable').DataTable({
            pageLength: 25,
            order: [[4, 'desc']],
        });
    });

    document.querySelectorAll('.copy-btn').forEach(btn => {
        btn.addEventListener('click', function () {
            const target = document.getElementById(this.dataset.target);
            if (target) {
                navigator.clipboard.writeText(target.value).then(() => {
                    alert('Copied to clipboard!');
                });
            }
        });
    });
</script>
@endpush

@push('style')
<link href="https://cdn.datatables.net/1.13.5/css/jquery.dataTables.min.css" rel="stylesheet"/>
@endpush
