@extends('admin.layouts.app')

@section('panel')
    <div class="row">
        <div class="col-lg-12">
            {{-- Binary Commission Settings --}}
            <div class="card mb-4">
                <div class="card-header bg-primary text-white d-flex justify-content-between">
                    <h5 class="mb-0">@lang('Binary Commission List')</h5>
                </div>
                <div class="card-body">
                    <form method="POST" action="{{ route('admin.binaryCommission.updateSettings') }}">
                        @csrf
                        <div class="table-responsive">
                            <table class="table table-bordered">
                                <thead>
                                    <tr>
                                        <th>@lang('Generation')</th>
                                        <th>@lang('Commission (%)')</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach($commissionRates as $generation => $rate)
                                        <tr>
                                            <td>@lang('Generation') {{ $generation }}</td>
                                            <td>
                                                <input type="number" name="rates[{{ $generation }}]" class="form-control"
                                                    value="{{ $rate }}" step="0.01" required>
                                            </td>
                                        </tr>
                                    @endforeach
                                    {{-- Add Binary Commission Minimum Purchase Setting --}}
                                    <tr>
                                        <td>@lang('Minimum Purchase ($)')</td>
                                        <td>
                                            <input type="number" name="minimum_purchase" class="form-control"
                                                value="{{ old('minimum_purchase', $binaryCommissionMinimumPurchase) }}" step="0.01" required>
                                        </td>
                                    </tr>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                        <button type="submit" class="btn btn-primary w-100">@lang('Update Settings')</button>
                    </form>
                </div>
            </div>
   
            {{-- Add Binary Commission Modal --}}
            <div class="modal fade" id="add-binary-commission" role="dialog" tabindex="-1">
                <div class="modal-dialog modal-dialog-centered modal-md" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title">@lang('Add New Binary Commission')</h5>
                            <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                                <i class="las la-times"></i>
                            </button>
                        </div>
                        <form id="addCommissionForm" method="POST" action="{{ route('admin.binaryCommission.store') }}">
                            @csrf
                            <div class="modal-body">
                                <div class="form-group">
                                    <label>@lang('User')</label>
                                    <select class="form-control" name="user_id" required>
                                        @foreach($users as $user)
                                            <option value="{{ $user->id }}">{{ $user->username }}</option>
                                        @endforeach
                                    </select>
                                </div>
                                <div class="form-group">
                                    <label>@lang('Amount ($)')</label>
                                    <input class="form-control amount" name="amount" type="number" step="0.01" required>
                                </div>
                            </div>
                            <div class="modal-footer">
                                <button class="btn btn--primary w-100" type="submit">@lang('Submit')</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>

@endsection

@push('script')
<script>
    (function ($) {
        "use strict";
        
        $('.edit').on('click', function() {
            let modal = $('#edit-binary-commission');
            modal.find('.commission_id').val($(this).data('id'));
            modal.find('.user').text($(this).data('user'));
            modal.find('.amount').val($(this).data('amount'));
            modal.modal('show');
        });

        $('.add-binary-commission').on('click', function() {
            $('#add-binary-commission').modal('show');
        });

        $('.edit-settings').on('click', function() {
            $('input[name^="rates"], input[name="minimum_purchase"]').prop('disabled', false);
        });

        $('#addCommissionForm').on('submit', function (e) {
            e.preventDefault();
            let form = $(this);
            $.ajax({
                url: form.attr('action'),
                type: "POST",
                data: form.serialize(),
                success: function (response) {
                    if (response.success) {
                        notify('success', response.message);
                        location.reload();
                    } else {
                        notify('error', response.message);
                    }
                },
                error: function (xhr) {
                    let errors = xhr.responseJSON.errors;
                    $.each(errors, function (key, value) {
                        notify('error', value[0]);
                    });
                }
            });
        });

    })(jQuery);
</script>
@endpush
