@extends('admin.layouts.app')

@section('panel')
    <div class="row">
        <div class="col-lg-12">
            <div class="card">
                <div class="card-header d-flex justify-content-between">
                    <h4>@lang('House Fund Wallets')</h4>
                    <button class="btn btn-primary settings-btn">@lang('Settings')</button>
                </div>
                <div class="card-body">
                    <div class="table-responsive">
                        <table class="table table-bordered">
                            <thead>
                                <tr>
                                    <th>@lang('User')</th>
                                    <th>@lang('Balance')</th>
                                    <th>@lang('Contributions')</th>
                                    <th>@lang('Redemptions')</th>
                                    <th>@lang('Actions')</th>
                                </tr>
                            </thead>
                            <tbody>
                            @foreach($wallets as $wallet)
                                <tr>
                                    <td>
                                        @if($wallet->user)
                                            {{ $wallet->user->firstname }} {{ $wallet->user->lastname ?? '' }}
                                        @else
                                            <span class="text-danger">⚠️ No User Found</span>
                                        @endif
                                    </td>
                                    <td>${{ number_format($wallet->balance, 2) }}</td>
                                    <td>${{ number_format($wallet->contributions()->sum('amount'), 2) }}</td>
                                    <td>${{ number_format($wallet->redemptions()->sum('amount'), 2) }}</td>
                                    <td>
                                        <button class="btn btn-info btn-sm show-wallet-btn"
                                            data-userid="{{ $wallet->user_id }}"
                                            data-username="{{ $wallet->user->firstname ?? 'N/A' }}"
                                            data-balance="{{ $wallet->balance }}"
                                            data-contributions="{{ $wallet->contributions()->sum('amount') }}"
                                            data-redemptions="{{ $wallet->redemptions()->sum('amount') }}">
                                            @lang('View')
                                        </button>

                                        <button class="btn btn-success btn-sm update-balance-btn"
                                            data-userid="{{ $wallet->user_id }}"
                                            data-balance="{{ $wallet->balance }}">
                                            @lang('Update Balance')
                                        </button>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                        </table>
                    </div>
                    @if ($wallets->hasPages())
                        <div class="card-footer">
                            {{ $wallets->links() }}
                        </div>
                    @endif
                </div>
            </div>
        </div>
    </div>
    
    <!-- Wallet Details Modal -->
    <div class="modal fade" id="walletDetailsModal" tabindex="-1">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Wallet Details')</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <h5>@lang('User'): <span id="walletUser"></span></h5>
                    <h5>@lang('Balance'): <span id="walletBalance"></span></h5>
                    <h5>@lang('Contributions'): <span id="walletContributions"></span></h5>
                    <h5>@lang('Redemptions'): <span id="walletRedemptions"></span></h5>
                    <div id="walletActions" class="mt-3"></div> <!-- Buttons will be added here -->
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">@lang('Close')</button>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Update Balance Modal -->
    <div class="modal fade" id="updateBalanceModal" tabindex="-1">
        <div class="modal-dialog">
            <form id="updateBalanceForm">
                @csrf
                <input type="hidden" name="user_id" id="updateUserId">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">@lang('Update Balance')</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <label>@lang('New Balance')</label>
                        <input type="number" step="0.01" class="form-control" name="balance" id="updateBalance" required>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">@lang('Update')</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">@lang('Close')</button>
                    </div>
                </div>
            </form>
        </div>
    </div>

    <!-- House Fund Wallet Settings -->
    @php
    use Illuminate\Support\Facades\DB;
    $settings = [
        'redeem_threshold' => DB::table('settings')->where('key', 'house_fund.redeem_threshold')->value('value') ?? 1000,
        'house_fund_percentage' => DB::table('settings')->where('key', 'house_fund.percentage')->value('value') ?? 10
        ];
    @endphp 
    <div class="card mb-3">
        <div class="card-body">
            <h5>@lang('House Fund Wallet Settings')</h5>
            <p>@lang('Current Redemption Threshold'): <span id="displayThreshold">{{ $settings['redeem_threshold'] }} USD</span></p>
            <p>@lang('Current House Fund Percentage'): <span id="displayPercentage">{{ $settings['house_fund_percentage'] }} %</span></p>  
            <button class="btn btn-primary settings-btn">@lang('Edit Settings')</button>
        </div>
    </div>

    <!-- House Fund Wallet Settings Modal -->
    <div class="modal fade" id="settingsModal" tabindex="-1">
        <div class="modal-dialog">
            <form id="settingsForm">
                @csrf
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">@lang('Update House Fund Settings')</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                    </div>
                    <div class="modal-body">
                        <label>@lang('Redemption Threshold ($)')</label>
                        <input type="number" name="redeem_threshold" id="redeemThresholdInput" value="{{ $settings['redeem_threshold'] }}" class="form-control" required>

                        <label class="mt-2">@lang('House Fund Percentage (%)')</label>
                        <input type="number" name="house_fund_percentage" id="houseFundPercentageInput" value="{{ $settings['house_fund_percentage'] }}" class="form-control" required>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">@lang('Update Settings')</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">@lang('Close')</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
@endsection

@push('script')
<script>
document.addEventListener("DOMContentLoaded", function () {
    console.log("✅ Page Loaded - Event Listeners Attached!");

    // ✅ Open Settings Modal
    document.querySelectorAll(".settings-btn").forEach(button => {
        button.addEventListener("click", function () {
            console.log("⚙️ Edit Settings Clicked!");
            let modal = new bootstrap.Modal(document.getElementById("settingsModal"));
            modal.show();
        });
    });

    // ✅ Handle Settings Update via AJAX
    document.querySelector("#settingsForm").addEventListener("submit", function (event) {
        event.preventDefault(); // Prevent default form submission

        let formData = new FormData(this);
        let url = `{{ url('/admin/house-fund-wallet/update-settings') }}`;

        fetch(url, {
            method: "POST",
            body: formData,
            headers: {
                "X-CSRF-TOKEN": document.querySelector('meta[name="csrf-token"]').getAttribute("content"),
                "X-Requested-With": "XMLHttpRequest"
            }
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert("✅ Settings updated successfully!");

                // ✅ Fetch updated settings from the server
                fetchSettings();

                // Close the modal properly
                let settingsModal = bootstrap.Modal.getInstance(document.getElementById("settingsModal"));
                settingsModal.hide();
            } else {
                alert("❌ Error updating settings. Try again.");
            }
        })
        .catch(error => console.error("❌ Error:", error));
    });

    // ✅ Fetch Updated Settings from Database and Update UI
    function fetchSettings() {
        fetch(`{{ url('/admin/house-fund-wallet/get-settings') }}`)
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    document.getElementById("displayThreshold").textContent = `${data.updated_settings.redeem_threshold} USD`;
                    document.getElementById("displayPercentage").textContent = `${data.updated_settings.house_fund_percentage} %`;
                    console.log("🔄 UI Updated with New Settings:", data.updated_settings);
                } else {
                    console.error("❌ Failed to fetch updated settings.");
                }
            })
            .catch(error => console.error("❌ Error fetching settings:", error));
    }

    // ✅ Handle "View Wallet" Button Click
    document.addEventListener("click", function (event) {
        if (event.target.classList.contains("show-wallet-btn")) {
            let walletModal = new bootstrap.Modal(document.getElementById("walletDetailsModal"));
            
            // Set modal values
            document.getElementById("walletUser").textContent = event.target.getAttribute("data-username");
            document.getElementById("walletBalance").textContent = `$${event.target.getAttribute("data-balance")}`;
            document.getElementById("walletContributions").textContent = `$${event.target.getAttribute("data-contributions")}`;
            document.getElementById("walletRedemptions").textContent = `$${event.target.getAttribute("data-redemptions")}`;
            
            // Add Approve and Reject buttons dynamically if redemptions exist
            let actionsContainer = document.getElementById("walletActions");
            actionsContainer.innerHTML = ""; // Clear previous actions
            
            let userId = event.target.getAttribute("data-userid");

            if (parseFloat(event.target.getAttribute("data-redemptions")) > 0) {
                actionsContainer.innerHTML = `
                    <button class="btn btn-success approve-redemption-btn" data-userid="${userId}">✅ Approve</button>
                    <button class="btn btn-danger reject-redemption-btn" data-userid="${userId}">❌ Reject</button>
                `;
            }

            walletModal.show();
        }
    });

    document.addEventListener("click", function (event) {
    // ✅ Approve Redemption Button Click
    if (event.target.classList.contains("approve-redemption-btn")) {
        let redemptionId = event.target.getAttribute("data-redemptionid");

        if (!redemptionId) {
            alert("❌ Error: Redemption ID is missing.");
            return;
        }

        if (confirm("Are you sure you want to approve this redemption?")) {
            fetch(`/admin/house-fund-wallet/approve-redemption/${redemptionId}`, {
                method: "POST",
                headers: {
                    "Content-Type": "application/json",
                    "X-CSRF-TOKEN": document.querySelector('meta[name="csrf-token"]').getAttribute("content"),
                    "X-Requested-With": "XMLHttpRequest"
                },
                body: JSON.stringify({ redemption_id: redemptionId }) // ✅ Send required data
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert("✅ Redemption approved successfully!");
                    window.location.reload(); // ✅ Refresh UI
                } else {
                    alert("❌ Error approving redemption: " + (data.error || "Unknown error"));
                }
            })
            .catch(error => {
                console.error("❌ Error:", error);
                alert("❌ Error processing request. Check console.");
            });
        }
    }

    // ✅ Reject Redemption Button Click
    if (event.target.classList.contains("reject-redemption-btn")) {
        let redemptionId = event.target.getAttribute("data-redemptionid");

        if (!redemptionId) {
            alert("❌ Error: Redemption ID is missing.");
            return;
        }

        if (confirm("Are you sure you want to reject this redemption?")) {
            fetch(`/admin/house-fund-wallet/reject-redemption/${redemptionId}`, {
                method: "POST",
                headers: {
                    "Content-Type": "application/json",
                    "X-CSRF-TOKEN": document.querySelector('meta[name="csrf-token"]').getAttribute("content"),
                    "X-Requested-With": "XMLHttpRequest"
                },
                body: JSON.stringify({ redemption_id: redemptionId }) // ✅ Send required data
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert("❌ Redemption request rejected.");
                    window.location.reload(); // ✅ Refresh UI
                } else {
                    alert("❌ Error rejecting redemption: " + (data.error || "Unknown error"));
                }
            })
            .catch(error => {
                console.error("❌ Error:", error);
                alert("❌ Error processing request. Check console.");
            });
        }
    }
});

    // ✅ Handle "Update Balance" Button Click
    document.addEventListener("click", function (event) {
        if (event.target.classList.contains("update-balance-btn")) {
            console.log("💰 Update Balance Button Clicked");

            let userIdElement = document.getElementById("updateUserId");
            let balanceInputElement = document.getElementById("updateBalance");

            if (userIdElement && balanceInputElement) {
                userIdElement.value = event.target.getAttribute("data-userid");
                balanceInputElement.value = event.target.getAttribute("data-balance");

                let updateBalanceModal = new bootstrap.Modal(document.getElementById("updateBalanceModal"));
                updateBalanceModal.show();
            } else {
                console.error("❌ Error: Update Balance elements are missing.");
            }
        }
    });

    // ✅ Handle Balance Update Form Submission
    document.querySelector("#updateBalanceForm").addEventListener("submit", function (event) {
        event.preventDefault();
        let formData = new FormData(this);
        fetch("{{ url('/admin/house-fund-wallet/update-balance') }}", {
            method: "POST",
            body: formData,
            headers: {
                "X-CSRF-TOKEN": "{{ csrf_token() }}",
                "X-Requested-With": "XMLHttpRequest"
            }
        })
        .then(response => response.json())
        .then(data => {
            if (data.success) {
                alert("✅ Balance updated successfully!");
                window.location.reload();
            } else {
                alert("❌ Error updating balance. Try again.");
            }
        })
        .catch(error => console.error("❌ Error:", error));
    });
});
</script>
@endpush