@extends('admin.layouts.app')

@section('panel')
<div class="card">
    <div class="card-header">
        <h4>@lang('Manage Orders')</h4>
    </div>
    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-bordered">
                <thead>
                    <tr>
                        <th>@lang('Order ID')</th>
                        <th>@lang('User')</th>
                        <th>@lang('Total Amount')</th>
                        <th>@lang('Status')</th>
                        <th>@lang('Tracking')</th>
                        <th>@lang('Actions')</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($orders as $order)
                        <tr>
                            <td>#{{ $order->id }}</td>
                            <td>{{ $order->user->name }}</td>
                            <td>${{ number_format($order->total_price, 2) }}</td>
                            <td>
                                <span class="badge bg-{{ $order->status === 'completed' ? 'success' : ($order->status === 'shipped' ? 'info' : 'warning') }}">
                                    {{ ucfirst($order->status) }}
                                </span>
                            </td>
                            <td>
                                {{ $order->tracking_code }}
                            </td>
                            <td>
                                <button class="btn btn-info btn-sm view-order"
                                    data-id="{{ $order->id }}"
                                    data-user="{{ $order->user->name }}"
                                    data-total="{{ $order->total_price }}"
                                    data-status="{{ ucfirst($order->status) }}"
                                    data-notes="{{ $order->notes ?? 'No notes available' }}"
                                    data-bs-toggle="modal" data-bs-target="#order-details-modal">
                                    @lang('View')
                                </button>
                                <form method="POST" action="{{ route('admin.orders.updateStatus', $order->id) }}" class="d-inline">
                                    @csrf
                                    @method('PUT')
                                    <select name="status" class="form-select form-select-sm d-inline w-auto" onchange="this.form.submit()">
                                        <option value="pending" {{ $order->status === 'pending' ? 'selected' : '' }}>@lang('Pending')</option>
                                        <option value="approved" {{ $order->status === 'approved' ? 'selected' : '' }}>@lang('Approved')</option>
                                        <option value="shipped" {{ $order->status === 'shipped' ? 'selected' : '' }}>@lang('Shipped')</option>
                                        <option value="delivered" {{ $order->status === 'delivered' ? 'selected' : '' }}>@lang('Delivered')</option>
                                        <option value="completed" {{ $order->status === 'completed' ? 'selected' : '' }}>@lang('Completed')</option>
                                        <option value="canceled" {{ $order->status === 'canceled' ? 'selected' : '' }}>@lang('Canceled')</option>
                                    </select>
                                </form>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
        <div class="mt-3">
            {{ $orders->links() }}
        </div>
    </div>
</div>

<!-- Order Details Modal -->
<div class="modal fade" id="order-details-modal" tabindex="-1">
    <div class="modal-dialog modal-dialog-centered modal-md">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">@lang('Order Details')</h5>
                <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                    <i class="las la-times"></i>
                </button>
            </div>
            <div class="modal-body">
                <p><strong>@lang('Order ID'):</strong> <span id="order-id"></span></p>
                <p><strong>@lang('User'):</strong> <span id="order-user"></span></p>
                <p><strong>@lang('Total Amount'):</strong> $<span id="order-total"></span></p>
                <p><strong>@lang('Status'):</strong> <span id="order-status"></span></p>
                <p><strong>@lang('Notes'):</strong> <span id="order-notes"></span></p>
            </div>
            <div class="modal-footer">
                <button class="btn btn-secondary" data-bs-dismiss="modal">@lang('Close')</button>
            </div>
        </div>
    </div>
</div>
@endsection

@push('script')
<script>
    (function ($) {
        "use strict";
        $('.view-order').on('click', function() {
            $('#order-id').text($(this).data('id'));
            $('#order-user').text($(this).data('user'));
            $('#order-total').text($(this).data('total'));
            $('#order-status').text($(this).data('status'));
            $('#order-notes').text($(this).data('notes'));
        });
    })(jQuery);
</script>
@endpush
