@extends('admin.layouts.app')

@section('panel')
<div class="row">
    <div class="col-lg-12">
        <div class="card">
            <div class="card-body p-0">
                <div class="table-responsive--md table-responsive">
                    <table class="table--light style--two table">
                        <thead>
                            <tr>
                                <th>@lang('Name')</th>
                                <th>@lang('Price')</th>
                                <th>@lang('Business Volume (BV)')</th>
                                <th>@lang('Referral Commission')</th>
                                <th>@lang('Max Pairs Per Day')</th>
                                <th>@lang('Infinite Pairs')</th>
                                <th>@lang('Share Limit')</th>
                                <th>@lang('Share Commission')</th>
                                <th>@lang('Plan Picture')</th>
                                <th>@lang('Status')</th>
                                <th>@lang('Action')</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($plans as $plan)
                            <tr>
                                <td>{{ $plan->name }}</td>
                                <td>{{ showAmount($plan->price) }}</td>
                                <td>{{ $plan->bv }}</td>
                                <td>{{ showAmount($plan->ref_com) }}</td>
                                <td>{{ $plan->max_pairs_count }} Pairs - {{ showAmount($plan->max_pairs_amount) }}</td>
                                <td>{{ showAmount($plan->infinite_pairs) }}</td>
                                <td>{{ $plan->product_share_limit }}</td>
                                <td>{{ showAmount($plan->product_share_commission) }}</td>
                                <td>
                                    @if ($plan->plan_picture)
                                    <img src="{{ asset('assets/images/plan/' . $plan->plan_picture) }}" class="w-80 img-thumbnail" alt="Plan Image">
                                    @else
                                    <img src="{{ asset('assets/images/plan/default.jpg') }}" class="w-80 img-thumbnail" alt="Default Image">
                                    @endif
                                </td>
                                <td>{!! $plan->statusBadge !!}</td>
                                <td>
                                    <button class="btn btn-sm btn-outline--primary edit" data-id="{{ $plan->id }}" data-name="{{ $plan->name }}" data-price="{{ getAmount($plan->price) }}" data-bv="{{ $plan->bv }}" data-ref_com="{{ getAmount($plan->ref_com) }}" data-max_pairs_count="{{ $plan->max_pairs_count }}" data-max_pairs_amount="{{ getAmount($plan->max_pairs_amount) }}" data-infinite_pairs="{{ $plan->infinite_pairs }}" data-product_share_limit="{{ $plan->product_share_limit }}" data-product_share_commission="{{ getAmount($plan->product_share_commission) }}" data-plan_picture="{{ asset('assets/images/plan/'.$plan->plan_picture) }}" type="button">
                                        <i class="la la-pencil"></i> @lang('Edit')
                                    </button>

                                    @if ($plan->status == Status::DISABLE)
                                    <button class="btn btn-sm btn-outline--success confirmationBtn ms-1" data-question="@lang('Are you sure to enable this plan?')" data-action="{{ route('admin.plan.status', $plan->id) }}">
                                        <i class="la la-eye"></i> @lang('Enable')
                                    </button>
                                    @else
                                    <button class="btn btn-sm btn-outline--danger confirmationBtn ms-1" data-question="@lang('Are you sure to disable this plan?')" data-action="{{ route('admin.plan.status', $plan->id) }}">
                                        <i class="la la-eye-slash"></i> @lang('Disable')
                                    </button>
                                    @endif

                                </td>
                            </tr>
                            @empty
                            <tr>
                                <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                            </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
            @if ($plans->hasPages())
            <div class="card-footer py-4">
                {{ $plans->links() }}
            </div>
            @endif
        </div>
    </div>
</div>

{{-- Edit Plan Modal --}}
<div class="modal fade" id="edit-plan" tabindex="-1">
    <div class="modal-dialog modal-dialog-centered modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">@lang('Edit Plan')</h5>
                <button class="close" data-bs-dismiss="modal" type="button">
                    <i class="las la-times"></i>
                </button>
            </div>
            <form method="POST" action="{{ route('admin.plan.save') }}" enctype="multipart/form-data">
                @csrf
                <div class="modal-body">
                    <input class="form-control plan_id" name="id" type="hidden">
                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Name')</label>
                            <input class="form-control name" name="name" type="text" required>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Price')</label>
                            <input class="form-control price" name="price" type="number" step="any" required>
                        </div>
                    </div>
                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Business Volume (BV)')</label>
                            <input class="form-control bv" name="bv" type="number" required>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Referral Commission')</label>
                            <input class="form-control ref_com" name="ref_com" type="number" step="any" required>
                        </div>
                    </div>

                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Max Pairs Per Day')</label>
                            <div class="d-flex">
                                <input class="form-control max_pairs_count me-2" name="max_pairs_count" type="number" placeholder="Pairs Per Day" required>
                                <input class="form-control max_pairs_amount" name="max_pairs_amount" type="number" step="0.01" placeholder="Amount ($)" required>
                            </div>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Infinite Pairs (Unlimited Earning Amount)')</label>
                            <input class="form-control infinite_pairs" name="infinite_pairs" type="number" step="0.01" required>
                        </div>
                    </div>
                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Product Share Limit')</label>
                            <input class="form-control product_share_limit" name="product_share_limit" type="number" required>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Product Share Commission')</label>
                            <input class="form-control product_share_commission" name="product_share_commission" type="number" step="any" required>
                        </div>
                    </div>
                    <div class="form-group">
                        <label>@lang('Plan Picture')</label>
                        <input class="form-control" name="plan_picture" type="file">
                        <img src="{{ asset('assets/images/plan/default.jpg') }}" class="w-80 img-thumbnail image-preview" alt="Plan Image">
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn--primary w-100" type="submit">@lang('Submit')</button>
                </div>
            </form>
        </div>
    </div>
</div>

{{-- Add Plan Modal --}}
<div class="modal fade" id="add-plan" role="dialog" tabindex="-1">
    <div class="modal-dialog modal-dialog-centered modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">@lang('Add New Plan')</h5>
                <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                    <i class="las la-times"></i>
                </button>
            </div>
            <form method="POST" action="{{ route('admin.plan.save') }}" enctype="multipart/form-data">
                @csrf
                <div class="modal-body">
                    <input class="form-control plan_id" name="id" type="hidden">
                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Name')</label>
                            <input class="form-control name" name="name" type="text" required>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Price')</label>
                            <input class="form-control price" name="price" type="number" step="any" required>
                        </div>
                    </div>
                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Business Volume (BV)')</label>
                            <input class="form-control bv" name="bv" type="number" required>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Referral Commission')</label>
                            <input class="form-control ref_com" name="ref_com" type="number" step="any" required>
                        </div>
                    </div>

                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Max Pairs Per Day')</label>
                            <div class="d-flex">
                                <input class="form-control max_pairs_count me-2" name="max_pairs_count" type="number" placeholder="Pairs Per Day" required>
                                <input class="form-control max_pairs_amount" name="max_pairs_amount" type="number" step="0.01" placeholder="Amount ($)" required>
                            </div>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Infinite Pairs (Unlimited Earning Amount)')</label>
                            <input class="form-control infinite_pairs" name="infinite_pairs" type="number" step="0.01" required>
                        </div>
                    </div>
                    <div class="row">
                        <div class="form-group col-md-6">
                            <label>@lang('Product Share Limit')</label>
                            <input class="form-control product_share_limit" name="product_share_limit" type="number" required>
                        </div>
                        <div class="form-group col-md-6">
                            <label>@lang('Product Share Commission')</label>
                            <input class="form-control product_share_commission" name="product_share_commission" type="number" step="any" required>
                        </div>
                    </div>
                    <div class="form-group">
                        <label>@lang('Plan Picture')</label>
                        <input class="form-control" name="plan_picture" type="file">
                        <img src="{{ asset('assets/images/plan/default.jpg') }}" class="w-80 img-thumbnail image-preview" alt="Plan Image">
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn--primary w-100" type="submit">@lang('Submit')</button>
                </div>
            </form>
        </div>
    </div>
</div>

<x-confirmation-modal />
@endsection

@push('breadcrumb-plugins')
<button class="btn btn-sm btn-outline--primary add-plan" type="button">
    <i class="la la-plus"></i>@lang('Add New')
</button>
@endpush

@push('script')
<script>
"use strict";
(function($) {
    $('.edit').on('click', function() {
        var modal = $('#edit-plan');
        modal.find('.plan_id').val($(this).data('id'));
        modal.find('.name').val($(this).data('name'));
        modal.find('.price').val($(this).data('price'));
        modal.find('.bv').val($(this).data('bv'));
        modal.find('.ref_com').val($(this).data('ref_com'));
        modal.find('.max_pairs_count').val($(this).data('max_pairs_count'));
        modal.find('.max_pairs_amount').val($(this).data('max_pairs_amount'));
        modal.find('.infinite_pairs').val($(this).data('infinite_pairs'));
        modal.find('.product_share_limit').val($(this).data('product_share_limit'));
        modal.find('.product_share_commission').val($(this).data('product_share_commission'));
        modal.find('.image-preview').attr('src', $(this).data('plan_picture') && $(this).data('plan_picture') !== 'default.jpg' ? $(this).data('plan_picture') : '{{ asset("assets/images/plan/default.jpg") }}');
        modal.modal('show');
    });

    $('.add-plan').on('click', function() {
        var modal = $('#add-plan');
        modal.modal('show');
    });
})(jQuery);
</script>
@endpush