@extends('admin.layouts.app')

@section('panel')
<div class="row">
    <div class="col-lg-12">
        <div class="card b-radius--10">
            <div class="card-body p-0">
                <div class="table-responsive--md table-responsive">
                    <table class="table table--light style--two">
                        <thead>
                            <tr>
                                <th class="text-center">@lang('Image')</th>
                                <th class="text-start">@lang('Name')</th>
                                <th class="text-center">@lang('SKU')</th>
                                <th class="text-center">@lang('In Stock')</th>
                                <th class="text-end">@lang('Price')</th>
                                <th class="text-center">@lang('BV')</th>
                                <th class="text-center">@lang('Discount')</th>
                                <th class="text-end">@lang('Action')</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($products as $product)
                            <tr>
                                <td class="text-center">
                                    <img src="{{ getImage(getFilePath('product') . '/' . $product->image, getFileSize('product')) }}" 
                                         width="50" 
                                         onerror="this.src='{{ asset('assets/images/default-product.png') }}'" 
                                         alt="product">
                                </td>
                                <td class="text-start">{{ __($product->name) }}</td>
                                <td class="text-center">{{ __($product->sku) }}</td>
                                <td class="text-center">{{ __($product->stock) }}</td>
                                <td class="text-end">{{ showAmount($product->price) }}</td>
                                <td class="text-center">{{ __($product->bv) }}</td>
                                <td class="text-center">{{ __($product->discount) }}%</td>
                                <td class="text-end">
                                    <div class="btn-group">
                                        <button class="btn btn-sm btn-outline--primary editBtn me-1"
                                            data-product="{{ json_encode($product) }}"
                                            data-image="{{ getImage(getFilePath('product') . '/' . $product->image, getFileSize('product')) }}">
                                            <i class="las la-pen"></i> @lang('Edit')
                                        </button>
                                        <form action="{{ route('admin.products.destroy', $product->id) }}" method="POST" class="d-inline deleteForm">
                                            @csrf
                                            @method('DELETE')
                                            <button type="submit" class="btn btn-sm btn-outline--danger deleteBtn">
                                                <i class="las la-trash"></i> @lang('Delete')
                                            </button>
                                        </form>
                                    </div>
                                </td>
                            </tr>
                            @empty
                            <tr>
                                <td class="text-muted text-center" colspan="100%">{{ __($emptyMessage) }}</td>
                            </tr>
                            @endforelse
                        </tbody>
                    </table><!-- table end -->
                </div>
            </div>
        </div><!-- card end -->
    </div>
</div>

<!-- Product Modal -->
<div class="modal fade" id="productModal">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="productModalLabel">@lang('Add New Product')</h5>
                <button type="button" class="close" data-bs-dismiss="modal">
                    <i class="las la-times"></i>
                </button>
            </div>
            <form id="productForm" method="POST" enctype="multipart/form-data">
                @csrf
                <div id="methodField"></div> <!-- This field will be dynamically updated -->
                <div class="modal-body">
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-group text-center">
                                <label class="form-label">@lang('Image')</label>
                                <x-image-uploader name="image" image="{{ asset('assets/images/default-product.png') }}" class="w-100 image-preview" type="product" />
                            </div>
                        </div>
                        <div class="col-md-8">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label>@lang('Name') *</label>
                                        <input type="text" class="form-control" name="name" required>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label>@lang('SKU') *</label>
                                        <input type="text" class="form-control" name="sku" required>
                                    </div>
                                </div>
                            </div>
            
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label>@lang('In Stock') *</label>
                                        <input type="number" name="stock" class="form-control" required>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label>@lang('Price') *</label>
                                        <div class="input-group">
                                            <input type="number" step="any" name="price" min="0" class="form-control" required>
                                            <span class="input-group-text">{{ gs('cur_text') }}</span>
                                        </div>
                                    </div>
                                </div>
                            </div>
            
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label>@lang('Discount')</label>
                                        <div class="input-group">
                                            <input type="number" step="any" name="discount" min="0" class="form-control">
                                            <span class="input-group-text">%</span>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group">
                                        <label>@lang('BV')</label>
                                        <div class="input-group">
                                            <input type="number" step="any" name="bv" min="0" class="form-control">
                                            <span class="input-group-text">@lang('BV')</span>
                                        </div>
                                    </div>
                                </div>
                            </div>
            
                            <div class="form-group">
                                <label>@lang('Short Description')</label>
                                <textarea name="short_description" class="form-control" rows="2"></textarea>
                            </div>
            
                            <!-- 📝 Product Description (With WYSIWYG Editor) -->
                            <div class="mt-4">
                                <h5>Product Description</h5>
                                <textarea id="product-description" name="description" class="form-control"></textarea>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn--primary w-100">@lang('Submit')</button>
                </div>
            </form>
        </div>
    </div>
</div>
<x-confirmation-modal />
@endsection
@push('breadcrumb-plugins')
<div class="d-flex justify-content-end mb-3">
    <button class="btn btn-outline--primary btn-sm addBtn">
        <i class="las la-plus"></i> @lang('Add New Product')
    </button>
</div>
@endpush
@push('script')
<script src="https://cdn.tiny.cloud/1/toiq1xlcnbpx7slkp4gwfkb5sesqhrrrczsumio1oj9kbf84/tinymce/5/tinymce.min.js"></script>
<script>
    "use strict";

    function initializeTinyMCE() {
        tinymce.init({
            selector: '#product-description',
            menubar: false,
            plugins: 'advlist autolink lists link charmap print preview anchor',
            toolbar: 'bold italic underline | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent'
        });
    }

    (function ($) {
        let modal = $('#productModal');
        let form = $('#productForm');
        let action = `{{ route('admin.products.store') }}`;

        // Open Add Product Modal
        $('.addBtn').on('click', function () {
            form.attr('action', action);
            form.attr('method', 'POST');
            $('#methodField').html("");
            modal.modal('show');
            form[0].reset();
            modal.find('.image-preview').attr('src', '{{ asset("assets/images/default-product.png") }}');
            $('#productModalLabel').text('@lang("Add New Product")');
            
            // Reinitialize TinyMCE for the new modal content
            setTimeout(() => {
                tinymce.remove('#product-description'); 
                initializeTinyMCE();
            }, 300);
        });

        // Open Edit Product Modal
        $('.editBtn').on('click', function () {
            let product = $(this).data('product');
            let image = $(this).data('image');
            let editAction = `{{ route('admin.products.update', '') }}/${product.id}`;

            form.attr('action', editAction);
            form.attr('method', 'POST'); // Laravel only supports POST, so we manually add PUT
            $('#methodField').html('<input type="hidden" name="_method" value="PUT">');

            form.find('[name=name]').val(product.name);
            form.find('[name=sku]').val(product.sku);
            form.find('[name=stock]').val(product.stock);
            form.find('[name=price]').val(product.price);
            form.find('[name=bv]').val(product.bv);
            form.find('[name=discount]').val(product.discount);
            form.find('[name=short_description]').val(product.short_description);
            modal.find('.image-preview').attr('src', image || '{{ asset("assets/images/default-product.png") }}');

            // Fix for TinyMCE editor
            setTimeout(() => {
                tinymce.remove('#product-description'); 
                initializeTinyMCE();
                tinymce.get('product-description').setContent(product.description || '');
            }, 300);

            modal.modal('show');
            $('#productModalLabel').text('@lang("Edit Product")');
        });
    })(jQuery);
</script>
@endpush