@extends('admin.layouts.app')

@section('panel')
<div class="row">
    <div class="col-lg-12">
        {{-- Stockiest Management --}}
        <div class="card mb-4">
            <div class="card-header bg-primary text-white d-flex justify-content-between">
                <h5 class="mb-0">@lang('Stockiest List')</h5>
                <button class="btn btn-light add-stockiest" data-bs-toggle="modal" data-bs-target="#add-stockiest">@lang('Add Stockiest')</button>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table table-bordered">
                        <thead>
                            <tr>
                                <th>@lang('ID')</th>
                                <th>@lang('Name')</th>
                                <th>@lang('Email')</th>
                                <th>@lang('Phone')</th>
                                <th>@lang('Location')</th>
                                <th>@lang('Status')</th>
                                <th>@lang('Action')</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach($stockiests as $stockiest)
                            <tr>
                                <td>{{ $stockiest->id }}</td>
                                <td>{{ $stockiest->name }}</td>
                                <td>{{ $stockiest->email }}</td>
                                <td>{{ $stockiest->phone }}</td>
                                <td>{{ $stockiest->location }}</td>
                                <td>
                                    @if($stockiest->status)
                                    <span class="badge bg-success">@lang('Active')</span>
                                    @else
                                    <span class="badge bg-danger">@lang('Inactive')</span>
                                    @endif
                                </td>
                                <td>
                                    <button class="btn btn-sm btn-warning edit-stockiest"
                                        data-id="{{ $stockiest->id }}"
                                        data-name="{{ $stockiest->name }}"
                                        data-email="{{ $stockiest->email }}"
                                        data-phone="{{ $stockiest->phone }}"
                                        data-location="{{ $stockiest->location }}"
                                        data-status="{{ $stockiest->status }}"
                                        data-bs-toggle="modal" data-bs-target="#edit-stockiest">
                                        @lang('Edit')
                                    </button>
                                </td>
                            </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        {{-- Add Stockiest Modal --}}
        <div class="modal fade" id="add-stockiest" tabindex="-1">
            <div class="modal-dialog modal-dialog-centered modal-md">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">@lang('Add New Stockiest')</h5>
                        <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                            <i class="las la-times"></i>
                        </button>
                    </div>
                    <form id="addStockiestForm" method="POST" action="{{ route('admin.stockiest.store') }}">
                        @csrf
                        <div class="modal-body">
                            <div class="form-group">
                                <label>@lang('Select User')</label>
                                <select class="form-control" name="user_id" id="userSelect">
                                    <option value="">@lang('Select Existing User')</option>
                                    @foreach($users as $user)
                                    <option value="{{ $user->id }}"
                                        data-name="{{ $user->name }}"
                                        data-email="{{ $user->email }}"
                                        data-phone="{{ $user->phone ?? '' }}">
                                        {{ $user->name }} - {{ $user->email }}
                                    </option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="form-group">
                                <label>@lang('Name')</label>
                                <input class="form-control" name="name" id="nameInput" type="text" required>
                            </div>
                            <div class="form-group">
                                <label>@lang('Email')</label>
                                <input class="form-control" name="email" id="emailInput" type="email" required>
                            </div>
                            <div class="form-group">
                                <label>@lang('Phone')</label>
                                <input class="form-control" name="phone" id="phoneInput" type="text" required>
                            </div>
                            <div class="form-group">
                                <label>@lang('Location')</label>
                                <input class="form-control" name="location" type="text" required>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button class="btn btn--primary w-100" type="submit">@lang('Submit')</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>

        {{-- Edit Stockiest Modal --}}
        <div class="modal fade" id="edit-stockiest" tabindex="-1">
            <div class="modal-dialog modal-dialog-centered modal-md">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">@lang('Edit Stockiest')</h5>
                        <button class="close" data-bs-dismiss="modal" type="button" aria-label="Close">
                            <i class="las la-times"></i>
                        </button>
                    </div>
                    <form id="editStockiestForm" method="POST">
                        @csrf
                        @method('PUT')
                        <div id="methodFieldEdit"></div> <!-- This field will be dynamically updated -->
                        <div class="modal-body">
                            <input type="hidden" class="form-control stockiest_id" name="id">
                            <div class="form-group">
                                <label>@lang('Name')</label>
                                <input class="form-control name" name="name" type="text" required>
                            </div>
                            <div class="form-group">
                                <label>@lang('Email')</label>
                                <input class="form-control email" name="email" type="email" required>
                            </div>
                            <div class="form-group">
                                <label>@lang('Phone')</label>
                                <input class="form-control phone" name="phone" type="text" required>
                            </div>
                            <div class="form-group">
                                <label>@lang('Location')</label>
                                <input class="form-control location" name="location" type="text" required>
                            </div>
                            <div class="form-group">
                                <label>@lang('Status')</label>
                                <select class="form-control status" name="status">
                                    <option value="1">@lang('Active')</option>
                                    <option value="0">@lang('Inactive')</option>
                                </select>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button class="btn btn--primary w-100" type="submit">@lang('Update')</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
@endsection

@push('script')
<script>
(function ($) {
    "use strict";

    // Autofill user details when selecting an existing user
    $('#userSelect').on('change', function() {
        let selectedUser = $(this).find(':selected');
        $('#nameInput').val(selectedUser.data('name') || '');
        $('#emailInput').val(selectedUser.data('email') || '');
        $('#phoneInput').val(selectedUser.data('phone') || '');
    });

    // Ensure the page refreshes after adding a Stockiest
    $('#addStockiestForm').on('submit', function (e) {
        e.preventDefault();
        let form = $(this);

        $.ajax({
            url: form.attr('action'),
            type: "POST",
            data: form.serialize(),
            success: function (response) {
                if (response.success) {
                    notify('success', response.message);
                    setTimeout(() => {
                        location.reload(); // Refresh the page
                    }, 1000);
                } else {
                    notify('error', response.message);
                }
            },
            error: function (xhr) {
                let errors = xhr.responseJSON.errors;
                $.each(errors, function (key, value) {
                    notify('error', value[0]);
                });
            }
        });
    });

    // Use event delegation for dynamically loaded Edit buttons
    $(document).on('click', '.edit-stockiest', function() {
    let modal = $('#edit-stockiest');

    // Populate form fields
    modal.find('.stockiest_id').val($(this).data('id'));
    modal.find('.name').val($(this).data('name'));
    modal.find('.email').val($(this).data('email'));
    modal.find('.phone').val($(this).data('phone'));
    modal.find('.location').val($(this).data('location'));
    modal.find('.status').val($(this).data('status'));

    // ✅ Fix: Set Correct Update URL
    let stockiestId = $(this).data('id');
    let updateAction = `/admin/stockiest/update/${stockiestId}`;
    $('#editStockiestForm').attr('action', updateAction);

    // ✅ Ensure the correct HTTP method
    $('#methodFieldEdit').html('<input type="hidden" name="_method" value="PUT">');

    // Show modal
    modal.modal('show');
});


    // Ensure the page refreshes after updating Stockiest
    $('#editStockiestForm').on('update', function (e) {
        e.preventDefault();
        let form = $(this);

        $.ajax({
            url: form.attr('action'),
            type: "POST",
            data: form.serialize(),
            success: function (response) {
                if (response.success) {
                    notify('success', response.message);
                    setTimeout(() => {
                        location.reload(); // Refresh page after update
                    }, 1000);
                } else {
                    notify('error', response.message);
                }
            },
            error: function (xhr) {
                let errors = xhr.responseJSON.errors;
                $.each(errors, function (key, value) {
                    notify('error', value[0]);
                });
            }
        });
    });

})(jQuery);
</script>
@endpush