@extends('templates.basic.layouts.frontend')

@push('page-title')
    {{ $pageTitle ?? 'Checkout' }}
@endpush

@section('content')
<div class="container py-5">
    <div class="row">
        <!-- 📝 Shipping Form -->
        <div class="col-md-8">
            <form action="{{ route('shipping.store') }}" method="POST">
                @csrf
                <div class="card">
                    <div class="card-header bg-primary text-white">
                        <h5 class="mb-0">Shipping Address</h5>
                    </div>
                    <div class="card-body">
                        @php
                            $selectedCountry = old('country') 
                                ?? ($shipping->country ?? (Auth::user()->country ?? ''));
                        @endphp
                        <div class="mb-3">
                            <label for="country" class="form-label">Country*</label>
                            <select name="country" id="country" class="form-control" required>
                            <option value="">Select Country</option>
                            @foreach($countries as $country)
                                <option value="{{ $country }}" 
                                    {{ $selectedCountry === $country ? 'selected' : '' }}>
                                    {{ $country }}
                                </option>
                            @endforeach
                        </select>
                        </div>

                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <label>First Name*</label>
                                <input type="text" name="first_name" class="form-control" value="{{ old('first_name', Auth::user()->firstname ?? '') }}" required>
                            </div>
                            <div class="col-md-6 mb-3">
                                <label>Last Name*</label>
                                <input type="text" name="last_name" class="form-control" value="{{ old('last_name', Auth::user()->lastname ?? '') }}" required>
                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <label>Phone Number*</label>
                                <div class="input-group">
                                    <span class="input-group-text" id="dial-code-display"></span>
                                    <input type="text" name="phone" id="phone" class="form-control" value="{{ old('phone', Auth::user()->mobile ?? '') }}" required>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <label>Email*</label>
                                <input type="email" name="email" class="form-control" value="{{ old('email', Auth::user()->email ?? '') }}" required>
                            </div>
                        </div>

                        <div class="mb-3">
                            <label>Address*</label>
                            <input type="text" name="address" id="autocomplete-address" class="form-control" value="{{ old('address', Auth::user()->address ?? '') }}" required>
                        </div>

                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <label>City*</label>
                                <input type="text" name="city" class="form-control" value="{{ old('city', Auth::user()->city ?? '') }}" required>
                            </div>
                            <div class="col-md-3 mb-3">
                                <label>State*</label>
                                <input type="text" name="state" class="form-control" value="{{ old('state', Auth::user()->state ?? '') }}" required>
                            </div>
                            <div class="col-md-3 mb-3">
                                <label>Postal Code*</label>
                                <input type="text" name="postal_code" class="form-control" value="{{ old('postal_code', Auth::user()->zip ?? '') }}" required>
                            </div>
                        </div>
                </div>
            </div>
        </div>

        <!-- 📦 Order Summary -->
        <div class="col-md-4">
            <div class="card shadow-sm">
                <div class="card-header bg-light fw-bold">Order Summary</div>
                <div class="card-body">
                    <p class="mb-2">Items: <span class="float-end">${{ number_format($total, 2) }}</span></p>
                    @php $discountAmount = $total - $totalDiscounted; @endphp
                    @if($discountAmount > 0)
                        <p class="mb-2 text-success">
                            Discount: <span class="float-end">- ${{ number_format($discountAmount, 2) }}</span>
                        </p>
                    @endif
                    <hr>
                    <h5>Total: <span class="float-end text-primary">${{ number_format($totalDiscounted, 2) }}</span></h5>

                    <div class="mt-3">
                        <label class="form-label">Payment Method*</label>
                        <select name="payment_method" class="form-control" required>
                            @foreach($paymentMethods as $method)
                                <option value="{{ $method->id }}">{{ $method->name }}</option>
                            @endforeach
                        </select>
                    </div>

                    <input type="hidden" name="total_price" value="{{ $totalDiscounted }}">

                    <div class="d-grid mt-4">
                        <button type="submit" class="btn btn-success btn-block">Proceed to Pay</button>
                    </div>
                </div>
            </div>
        </div>
        </form>
    </div>
</div>
@endsection

@push('script')
<script>
    document.addEventListener('DOMContentLoaded', function () {
        const dialingCodes = @json($dialingCodes);
        const countrySelect = document.getElementById('country');
        const dialCodeDisplay = document.getElementById('dial-code-display');
        const phoneInput = document.getElementById('phone');

        function updateDialCode() {
            const selectedCountry = countrySelect.value;
            if (dialingCodes[selectedCountry]) {
                dialCodeDisplay.textContent = dialingCodes[selectedCountry];
                if (!phoneInput.value.startsWith(dialingCodes[selectedCountry])) {
                    phoneInput.value = dialingCodes[selectedCountry];
                }
            } else {
                dialCodeDisplay.textContent = '';
            }
        }

        countrySelect.addEventListener('change', updateDialCode);
        updateDialCode();
    });
</script>

<script src="https://maps.googleapis.com/maps/api/js?key=YOUR_GOOGLE_MAPS_API_KEY&libraries=places"></script>
<script>
    function initAutocomplete() {
        const input = document.getElementById('autocomplete-address');
        if (input) {
            const autocomplete = new google.maps.places.Autocomplete(input);
        }
    }
    google.maps.event.addDomListener(window, 'load', initAutocomplete);
</script>
@endpush
