@extends('templates.basic.layouts.frontend')

@push('page-title')
    {{ $pageTitle }}
@endpush

@section('content')

<div class="container py-5">
    @if(session('success'))
        <div class="alert alert-success">
            {{ session('success') }} <br>
            <img src="https://api.qrserver.com/v1/create-qr-code/?data={{ urlencode(session('success')) }}&size=150x150" alt="QR Code">
        </div>
    @endif

    @if(isset($product))
    <!-- ✅ Single Product Display -->
    <div class="row">
        <div class="col-md-5">
            <img src="{{ asset('storage/products/' . $product->image) }}" class="img-fluid rounded shadow" alt="{{ $product->name }}">
        </div>

        <div class="col-md-7">
            <h3 class="fw-bold">{{ $product->name }}</h3>

            <!-- ✅ Selling Price & Discounted Price -->
            @php
                $discountedPrice = $product->price - ($product->price * ($product->discount / 100));
            @endphp

            <h4 class="fw-bold">
                <span class="text-primary">${{ number_format($discountedPrice, 2) }}</span>
                @if($product->discount > 0)
                    <small class="text-danger text-decoration-line-through fs-6 ms-2">
                        ${{ number_format($product->price, 2) }}
                    </small>
                @endif
            </h4>

            <!-- ✅ Stock & BV -->
            <div class="mt-3">
                <span class="badge bg-success fs-6 px-3 py-2">In Stock: {{ $product->stock }}</span>
                <span class="badge bg-warning fs-6 px-3 py-2 text-dark fw-bold">BV: {{ $product->bv }}</span>
            </div>

            <hr class="border-primary my-3"> 

            <p class="text-muted">{{ $product->short_description }}</p>

            <hr class="border-primary my-3"> 

            <!-- ✅ Quantity Selection & Buttons -->
            <div class="d-flex align-items-center mb-3">
                <button class="btn btn-outline-secondary btn-sm" id="decreaseQuantity">-</button>
                <input type="text" class="form-control text-center mx-2" id="quantity" value="1" style="width: 60px;">
                <button class="btn btn-outline-secondary btn-sm" id="increaseQuantity">+</button>
            </div>

            <button class="btn btn-primary btn-lg me-2 add-to-cart" data-id="{{ $product->id }}">
                <i class="fas fa-shopping-cart"></i> Add to Cart
            </button>

            <button class="btn btn-success btn-lg buy-now" data-id="{{ $product->id }}">
                <i class="fas fa-bolt"></i> Buy Now
            </button>

            <!-- ✅ Share Product Link Based on Plan -->
            @if(auth()->check())
                @php
                    $userPlan = auth()->user()->plan;
                    $shareLimit = $userPlan ? $userPlan->product_share_limit : 0;
                    $remainingShares = $shareLimit - auth()->user()->used_shares;
                @endphp
            
                @if($remainingShares > 0)
                    <p class="mt-3">
                        You have <strong>{{ $remainingShares }}</strong> opportunities to share product links and earn a commission.
                        <br>
                        <a href="{{ route('generateShareLink', ['product_id' => $product->id]) }}">Click to create your product share link.</a>
                    </p>
                @else
                    <p class="mt-3 text-danger">You have reached your product share limit.</p>
                @endif
            @endif
        </div>
    </div>

    <hr class="border-secondary my-3"> 
    
    <!-- 📝 Product Description -->
    <div class="mt-4">
        <p><h6>Product Description</h6></p>
        <p>{{ $product->description }}</p>
    </div>

    <hr class="border-secondary my-4">
    @endif

    <!-- ✅ All Products Listing -->
    <div class="row">
        @if(!empty($products) && count($products) > 0)
            @foreach($products as $product)
            <div class="col-md-3 mb-4">
                <div class="card product-card">
                    <img src="{{ asset('storage/products/' . $product->image) }}" class="card-img-top" alt="{{ $product->name }}">
                    <div class="card-body">
                        <h5 class="card-title">{{ $product->name }}</h5>
                        @php
                            $discountedPrice = $product->price - ($product->price * ($product->discount / 100));
                        @endphp
                        <p>
                            <b class="text-primary">${{ number_format($discountedPrice, 2) }}</b>
                            @if($product->discount > 0)
                                <small class="text-danger text-decoration-line-through">
                                    ${{ number_format($product->price, 2) }}
                                </small>
                            @endif
                        </p>
                        <p class="text-warning"><strong>BV: </strong> {{ $product->bv }}</p>
                        <a href="{{ route('store', ['product_id' => $product->id]) }}" class="btn btn-primary w-100">@lang('View')</a>
                    </div>
                </div>
            </div>
            @endforeach
        @else
            <p class="text-center">@lang('No products available.')</p>
        @endif
    </div>
</div>
@endsection

@push('script')
<script>
    document.addEventListener('DOMContentLoaded', function () {
        document.getElementById('increaseQuantity').addEventListener('click', function () {
            let qty = document.getElementById('quantity');
            qty.value = parseInt(qty.value) + 1;
        });

        document.getElementById('decreaseQuantity').addEventListener('click', function () {
            let qty = document.getElementById('quantity');
            if (parseInt(qty.value) > 1) {
                qty.value = parseInt(qty.value) - 1;
            }
        });

        document.querySelector('.add-to-cart').addEventListener('click', function () {
            let productId = this.getAttribute('data-id');
            let quantity = document.getElementById('quantity').value;

            fetch("{{ route('addToCart') }}", {
                method: "POST",
                headers: {
                    "Content-Type": "application/json",
                    "X-CSRF-TOKEN": "{{ csrf_token() }}"
                },
                body: JSON.stringify({ product_id: productId, quantity: quantity })
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    document.querySelector('.cart-count').innerText = data.cartCount;
                    alert(data.message);
                } else {
                    alert('Failed to add product to cart.');
                }
            });
        });

        document.querySelectorAll('.buy-now').forEach(button => {
            button.addEventListener('click', function () {
                let productId = this.getAttribute('data-id');
                let quantity = document.getElementById('quantity').value;

                let isAuthenticated = @json(auth()->check());

                if (!isAuthenticated) {
                    @if(Route::has('login'))
                        window.location.href = "{{ route('login') }}?redirect=" + encodeURIComponent("{{ route('checkout') }}?product_id=" + productId + "&quantity=" + quantity);
                    @else
                        alert('Login route not found. Please contact support.');
                    @endif
                } else {
                    window.location.href = "{{ route('checkout') }}?product_id=" + productId + "&quantity=" + quantity;
                }
            });
        });
    });
</script>
@endpush
