@extends('templates.basic.layouts.frontend')

@section('content')
<div class="container">
    <h2>@lang('Shop Our Products')</h2>
    
    <div class="row">
        @foreach($products as $product)
        <div class="col-md-3">
            <div class="card product-card">
                <img src="{{ asset('assets/images/products/' . $product->image) }}" class="card-img-top" alt="{{ $product->name }}">
                <div class="card-body">
                    <h5 class="card-title">{{ $product->name }}</h5>
                    <p>
                        <strike>${{ number_format($product->price, 2) }}</strike> 
                        <b>${{ number_format($product->price - ($product->price * $product->discount / 100), 2) }}</b> 
                        <span class="badge bg-success">{{ $product->discount }}% Off</span>
                    </p>
                    <button class="btn btn-primary view-product-btn" 
                        data-id="{{ $product->id }}" 
                        data-name="{{ $product->name }}"
                        data-price="{{ $product->price }}"
                        data-discount="{{ $product->discount }}"
                        data-bv="{{ $product->bv }}"
                        data-image="{{ asset('assets/images/products/' . $product->image) }}"
                        data-description="{{ $product->description }}">
                        @lang('View Details')
                    </button>
                    <button class="btn btn-success add-to-cart-btn" data-id="{{ $product->id }}">@lang('Add to Cart')</button>
                    <button class="btn btn-warning generate-affiliate-link" data-product-id="{{ $product->id }}">@lang('Share & Earn')</button>
                </div>
            </div>
        </div>
        @endforeach
    </div>
</div>

<!-- Affiliate Link Modal -->
<div class="modal fade" id="affiliateLinkModal" tabindex="-1">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5>@lang('Affiliate Link')</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <input type="text" id="affiliateLink" class="form-control" readonly>
                <button class="btn btn-primary mt-2" onclick="copyAffiliateLink()">@lang('Copy Link')</button>
            </div>
        </div>
    </div>
</div>
@endsection

@push('script')
<script>
    document.addEventListener("DOMContentLoaded", function() {
        document.querySelectorAll(".generate-affiliate-link").forEach(button => {
            button.addEventListener("click", function() {
                let productId = this.getAttribute("data-product-id");
                fetch(`/affiliate/generate/${productId}`)
                    .then(response => response.json())
                    .then(data => {
                        document.getElementById("affiliateLink").value = data.link;
                        new bootstrap.Modal(document.getElementById("affiliateLinkModal")).show();
                    });
            });
        });
    });

    function copyAffiliateLink() {
        let input = document.getElementById("affiliateLink");
        input.select();
        document.execCommand("copy");
        alert("Affiliate link copied!");
    }
</script>
@endpush
