@extends($activeTemplate . 'layouts.master')

@section('content')
<div class="container-fluid px-4">
    <h3 class="mb-4">@lang('Affiliate - Program')</h3>

    @php
        $sharedLinks = auth()->user()->sharedLinks ?? [];
    @endphp

    <div class="card">
        <div class="card-body">
            <h5 class="text-secondary mb-3">@lang('Your Shared Product Clicks')</h5>

            <div class="table-responsive" style="overflow-x: auto; min-height: 300px;">
                <table id="affiliateTable" class="table table-bordered table-striped align-middle w-100" style="min-width: 1010px;">
                    <thead class="table-green">
                        <tr>
                            <th>@lang('Product')</th>
                            <th>@lang('Share Link')</th>
                            <th>@lang('Clicks')</th>
                            <th>@lang('QR')</th>
                            <th>@lang('Created')</th>
                            <th>@lang('Location')</th>
                            <th>@lang('Referrer')</th>
                            <th>@lang('Last Click')</th>
                            <th>@lang('Actions')</th>
                        </tr>
                    </thead>
                    <tbody>
                        @forelse($sharedLinks as $link)
                            <tr>
                                <td>{{ $link->product->name }}</td>
                                <td>
                                    @php
                                        $shareUrl = $link->url ?? route('share.track', ['code' => $link->code]);
                                    @endphp
                                    <input type="text" id="link-{{ $link->id }}" value="{{ $shareUrl }}" class="d-none">
                                    <button class="btn btn-sm btn-outline-primary copy-btn" data-target="link-{{ $link->id }}">
                                        @lang('Copy')
                                    </button>
                                </td>
                                <td><strong>{{ $link->clicks }}</strong></td>
                                <td>
                                    <img src="https://api.qrserver.com/v1/create-qr-code/?data={{ urlencode($shareUrl) }}&size=80x80" alt="QR Code">
                                </td>
                                <td>{{ optional($link->created_at)->diffForHumans() ?? 'N/A' }}</td>
                                <td>
                                    @php
                                        $lastClick = $link->clicks()->latest()->first();
                                    @endphp
                                    {{ optional($lastClick)->country ?? 'N/A' }}{{ optional($lastClick)->city ? ', ' . $lastClick->city : '' }}
                                </td>
                                <td>{{ $lastClick->referrer ?? 'N/A' }}</td>
                                <td>{{ optional($link->last_clicked_at)->diffForHumans() ?? 'N/A' }}</td>
                                <td>
                                    <a href="{{ $shareUrl }}" class="btn btn-sm btn-outline-success" target="_blank">
                                        <i class="fas fa-external-link-alt"></i>
                                    </a>
                                </td>
                            </tr>
                        @empty
                            <tr>
                                <td colspan="9" class="text-center text-muted">@lang("You haven't shared any products yet.")</td>
                            </tr>
                        @endforelse
                    </tbody>
                </table>
            </div>

        </div>
    </div>
</div>
@endsection

@push('script')
<script src="https://cdn.datatables.net/1.13.5/js/jquery.dataTables.min.js"></script>
<script>
    document.querySelectorAll('.copy-btn').forEach(btn => {
        btn.addEventListener('click', function () {
            const inputId = this.dataset.target;
            const input = document.getElementById(inputId);
            if (input) {
                navigator.clipboard.writeText(input.value).then(() => {
                    alert('Copied to clipboard!');
                });
            }
        });
    });

    $(document).ready(function () {
        $('#affiliateTable').DataTable({
            pageLength: 10,
            order: [[2, 'desc']],
        });
    });
</script>
@endpush

@push('style')
<link href="https://cdn.datatables.net/1.13.5/css/jquery.dataTables.min.css" rel="stylesheet"/>
@endpush
