@extends($activeTemplate . 'layouts.master')

@push('page-title')
    {{ $pageTitle }}  {{-- Set the page title properly --}}
@endpush

@section('content')

    <div class="dashboard-inner">
        <div class="mb-4">
            <h3 class="mb-2">{{ $pageTitle }}</h3>
        </div>

        <div class="mb-4">
            <div class="card custom--card">
                <div class="card-header">
                    <h5 class="text-center">@lang('House Fund Details')</h5>
                </div>
                <div class="card-body">
                    <p><strong>@lang('Balance'):</strong> ${{ number_format($wallet->balance ?? 0, 2) }}</p>

                    @if(optional($wallet)->balance >= optional($wallet)->redeem_threshold)
                       <form method="POST" action="{{ route('user.housefund.redeem') }}">
                            @csrf
                            <input type="number" name="amount" min="1" max="{{ $wallet->balance }}" required>
                            <button type="submit" class="btn btn-success">@lang('Redeem Funds')</button>
                        </form>
                    @else
                        <p class="text-danger">
                            @lang('You need at least') ${{ number_format(optional($wallet)->redeem_threshold ?? 1000, 2) }} 
                            @lang('to redeem funds.')
                        </p>
                    @endif

                    <p><strong>@lang('Monthly Contribution'):</strong> ${{ number_format($wallet->monthly_contribution ?? 0, 2) }}</p>
                    <p><strong>@lang('Redemption Threshold'):</strong> ${{ number_format($wallet->redeem_threshold ?? 0, 2) }}</p>
                </div>
            </div>
        </div>

        <!-- Monthly Contribution History -->
        <div class="card custom--card mt-4">
            <div class="card-header">
                <h5 class="text-center">@lang('Monthly Contribution History')</h5>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>@lang('Month')</th>
                                <th>@lang('Amount')</th>
                                <th>@lang('Date')</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($monthlyContributions as $contribution)
                                <tr>
                                    <td>{{ date('F Y', strtotime($contribution->created_at)) }}</td>
                                    <td>${{ number_format($contribution->amount, 2) }}</td>
                                    <td>{{ date('d M, Y', strtotime($contribution->created_at)) }}</td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="3" class="text-center">@lang('No contributions found.')</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <!-- Redemption History -->
        <div class="card custom--card mt-4">
            <div class="card-header">
                <h5 class="text-center">@lang('Redemption History')</h5>
            </div>
            <div class="card-body">
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>@lang('Date')</th>
                                <th>@lang('Amount Redeemed')</th>
                                <th>@lang('Status')</th>
                            </tr>
                        </thead>
                        <tbody>
                            @forelse($redemptionHistory as $redemption)
                                <tr>
                                    <td>{{ date('d M, Y', strtotime($redemption->created_at)) }}</td>
                                    <td>${{ number_format($redemption->amount, 2) }}</td>
                                    <td>
                                        @if($redemption->status == 'approved')
                                            <span class="badge bg-success">@lang('Approved')</span>
                                        @elseif($redemption->status == 'pending')
                                            <span class="badge bg-warning">@lang('Pending')</span>
                                        @else
                                            <span class="badge bg-danger">@lang('Rejected')</span>
                                        @endif
                                    </td>
                                </tr>
                            @empty
                                <tr>
                                    <td colspan="3" class="text-center">@lang('No redemptions found.')</td>
                                </tr>
                            @endforelse
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

    </div>

@endsection

@push('style')
    <style>
        .badge {
            font-size: 14px;
            padding: 5px 10px;
            border-radius: 5px;
        }
    </style>
@endpush
