<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>Invoice #{{ $order->id }}</title>
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            font-size: 14px;
            padding: 20px;
            background-color: #f7f7f7;
        }
        .invoice-box {
            background: #fff;
            padding: 30px;
            border: 1px solid #ddd;
            border-radius: 6px;
            max-width: 800px;
            margin: auto;
        }
        h2, h4 {
            margin-bottom: 10px;
            color: #333;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }
        th, td {
            border: 1px solid #ccc;
            padding: 10px;
            text-align: left;
        }
        .header, .summary {
            margin-bottom: 20px;
        }
        .summary p {
            margin: 5px 0;
        }
        .total {
            font-weight: bold;
            font-size: 16px;
            margin-top: 10px;
        }
        .logo {
            text-align: right;
        }
        .logo img {
            height: 60px;
        }
        .footer {
            margin-top: 40px;
            text-align: center;
            font-size: 12px;
            color: #777;
        }
    </style>
</head>
<body>
<div class="invoice-box">
    <div class="header">
        <div style="display: flex; justify-content: space-between; align-items: center;">
            <div>
                <h2>Invoice</h2>
                <p><strong>Order ID:</strong> #{{ $order->id }}</p>
                <p><strong>Tracking Code:</strong> {{ $order->tracking_code }}</p>
                <p><strong>Date:</strong> {{ $order->created_at->format('d M, Y') }}</p>
            </div>
            <div class="logo">
                <img src="{{ public_path('assets/images/logo.png') }}" onerror="this.style.display='none'">
            </div>
        </div>
    </div>

    <div class="summary">
        <h4>Shipping Details</h4>
        <p>
            {{ $order->shipping->first_name }} {{ $order->shipping->last_name }}<br>
            {{ $order->shipping->address }}<br>
            {{ $order->shipping->city }}, {{ $order->shipping->state }}<br>
            {{ $order->shipping->postal_code }}, {{ $order->shipping->country }}<br>
            Phone: {{ $order->shipping->phone }}<br>
            Email: {{ $order->shipping->email }}
        </p>
    </div>

    <h4>Order Items</h4>
    <table>
        <thead>
            <tr>
                <th>#</th>
                <th>Product</th>
                <th>Qty</th>
                <th>Unit Price</th>
                <th>Total</th>
            </tr>
        </thead>
        <tbody>
            @foreach($order->items as $index => $item)
            <tr>
                <td>{{ $index + 1 }}</td>
                <td>{{ $item->product->name ?? 'Deleted Product' }}</td>
                <td>{{ $item->quantity }}</td>
                <td>${{ number_format($item->price, 2) }}</td>
                <td>${{ number_format($item->price * $item->quantity, 2) }}</td>
            </tr>
            @endforeach
        </tbody>
    </table>

    <p class="total">Total Paid: ${{ number_format($order->total_price, 2) }}</p>

    <div class="footer">
        Thank you for shopping with us.<br>
        If you have any questions, contact support@example.com
    </div>
</div>
</body>
</html>
