@extends('templates.basic.layouts.frontend')

@push('page-title')
    {{ $pageTitle ?? 'My Orders' }}
@endpush

@section('content')
@if(isset($trackingOrder))
<div class="container mb-4">
    <div class="alert alert-info">
        <h5 class="mb-2">🔍 Tracking Result</h5>
        <p><strong>Tracking Code:</strong> {{ $trackingOrder->tracking_code }}</p>
        <p><strong>Status:</strong> <span class="badge bg-{{ $trackingOrder->status === 'completed' ? 'success' : ($trackingOrder->status === 'shipped' ? 'info' : 'warning') }}">{{ ucfirst($trackingOrder->status) }}</span></p>
        <p><strong>Total:</strong> ${{ number_format($trackingOrder->total_price, 2) }}</p>
        <p><strong>Placed on:</strong> {{ $trackingOrder->created_at->format('d M, Y') }}</p>
    </div>
</div>
@endif

<div class="container py-5">
    <div class="row">
        <!-- 🔍 Track Order Form -->
        <div class="col-md-4">
            <div class="card mb-4">
                <div class="card-header bg-primary text-white">
                    <h5 class="mb-0">Track Order</h5>
                </div>
                <div class="card-body">
                    <form action="{{ route('order.track') }}" method="GET">
                        <div class="form-group mb-3">
                            <label for="tracking_code">Tracking Code</label>
                            <input type="text" name="tracking_code" class="form-control" required>
                        </div>
                        <button type="submit" class="btn btn-primary w-100">Track</button>
                    </form>
                </div>
            </div>
        </div>

        <!-- 📦 Order History -->
        <div class="col-md-8">
            <div class="card">
                <div class="card-header bg-light">
                    <h5 class="mb-0">My Order History</h5>
                </div>
                <div class="card-body p-0">
                    <div class="table-responsive">
                        <table class="table table-striped mb-0">
                            <thead>
                                <tr>
                                    <th>#</th>
                                    <th>Tracking</th>
                                    <th>Total</th>
                                    <th>Status</th>
                                    <th>Date</th>
<                                   th>Invoice</th>
                                </tr>
                            </thead>
                            <tbody>
                                @forelse($orders as $order)
                                <tr>
                                    <td>{{ $loop->iteration }}</td>
                                    <td><code>{{ $order->tracking_code }}</code></td>
                                    <td>${{ number_format($order->total_price, 2) }}</td>
                                    <td>
                                        <span class="badge bg-{{ $order->status === 'completed' ? 'success' : ($order->status === 'shipped' ? 'info' : 'warning') }}">
                                            {{ ucfirst($order->status) }}
                                        </span>
                                    </td>
                                    <td>{{ $order->created_at->format('d M, Y') }}</td>
                                    <td>
                                        <a href="{{ route('user.orders.invoice', $order->id) }}"
                                       class="btn btn-sm btn-success">
                                       Download PDF
                                    </a>
                                    </td>
                                </tr>
                                @empty
                                <tr>
                                    <td colspan="5" class="text-center">You have no orders yet.</td>
                                </tr>
                                @endforelse
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>

    </div>
</div>
@endsection
