@extends('user.layouts.app')

@section('content')
<div class="container">
    <h2 class="text-center">@lang('User Wallet')</h2>

    <div class="card p-3">
        <h4>@lang('Wallet Balance'): <b>${{ number_format(auth()->user()->balance, 2) }}</b></h4>
        
        <button class="btn btn-primary mt-3" data-bs-toggle="modal" data-bs-target="#depositModal">@lang('Deposit')</button>
        <button class="btn btn-danger mt-3" data-bs-toggle="modal" data-bs-target="#withdrawModal">@lang('Withdraw')</button>
    </div>

    <h3 class="mt-4">@lang('Transaction History')</h3>
    <table class="table">
        <thead>
            <tr>
                <th>@lang('Transaction ID')</th>
                <th>@lang('Amount')</th>
                <th>@lang('Type')</th>
                <th>@lang('Date')</th>
            </tr>
        </thead>
        <tbody>
            @foreach($transactions as $transaction)
            <tr>
                <td>{{ $transaction->trx }}</td>
                <td>${{ number_format($transaction->amount, 2) }}</td>
                <td>{{ $transaction->trx_type == '+' ? 'Deposit' : 'Withdrawal' }}</td>
                <td>{{ $transaction->created_at->format('Y-m-d') }}</td>
            </tr>
            @endforeach
        </tbody>
    </table>
</div>

<!-- Deposit Modal -->
<div class="modal fade" id="depositModal" tabindex="-1">
    <div class="modal-dialog">
        <form method="POST" action="{{ route('user.wallet.deposit') }}">
            @csrf
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Deposit Funds')</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <label>@lang('Amount')</label>
                    <input type="number" name="amount" class="form-control" required min="10">
                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn-primary">@lang('Deposit')</button>
                </div>
            </div>
        </form>
    </div>
</div>

<!-- Withdraw Modal -->
<div class="modal fade" id="withdrawModal" tabindex="-1">
    <div class="modal-dialog">
        <form method="POST" action="{{ route('user.wallet.withdraw') }}">
            @csrf
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">@lang('Withdraw Funds')</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <label>@lang('Amount')</label>
                    <input type="number" name="amount" class="form-control" required min="10">
                    <label>@lang('Withdrawal Method')</label>
                    <select name="method" class="form-control">
                        <option value="bank">@lang('Bank Transfer')</option>
                        <option value="crypto">@lang('Crypto')</option>
                    </select>
                </div>
                <div class="modal-footer">
                    <button type="submit" class="btn btn-danger">@lang('Withdraw')</button>
                </div>
            </div>
        </form>
    </div>
</div>
@endsection
