<?php 

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\SiteController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\CheckoutController;
use App\Http\Controllers\StoreController;
use App\Http\Controllers\ShippingController;
use App\Http\Controllers\User\Auth\LoginController;
use App\Http\Controllers\ShareController;
use App\Http\Controllers\User\AffiliateClickController;


// ðŸ”¹ Clear Cache Route
Route::get('/clear', function(){
    \Illuminate\Support\Facades\Artisan::call('optimize:clear');
});

// ðŸ”¹ User Support Ticket Routes
Route::controller('TicketController')->prefix('ticket')->name('ticket.')->group(function () {
    Route::get('/', 'supportTicket')->name('index');
    Route::get('new', 'openSupportTicket')->name('open');
    Route::post('create', 'storeSupportTicket')->name('store');
    Route::get('view/{ticket}', 'viewTicket')->name('view');
    Route::post('reply/{id}', 'replyTicket')->name('reply');
    Route::post('close/{id}', 'closeTicket')->name('close');
    Route::get('download/{attachment_id}', 'ticketDownload')->name('download');
    Route::post('/subscribe-plan', [UserController::class, 'subscribePlan'])->name('user.subscribe');
});

// ðŸ”¹ Store & Product Routes
    Route::get('/store', [StoreController::class, 'index'])->name('store.index');
    Route::get('/store/{product}', [StoreController::class, 'show'])->name('store.product');
    Route::get('/product/{id}', [StoreController::class, 'show'])->name('store.product');
    Route::get('/track-order', [UserOrderController::class, 'index'])->name('order.track');
    Route::get('/orders/invoice/{id}', [UserOrderController::class, 'invoice'])->name('user.orders.invoice')->middleware(['auth']);
    Route::get('/user/orders/{order}/invoice', [UserOrderController::class, 'downloadInvoice'])->name('user.orders.invoice')->middleware(['auth', 'checkstatus', 'registration.step']);
    Route::get('/share/generate/{product_id}', [ShareController::class, 'generate'])->name('generateShareLink')->middleware('auth');
    Route::get('/share/generate/{product_id}', [ShareController::class, 'generate'])->name('generateShareLink');
    Route::get('/s/{code}', [ShareController::class, 'track'])->name('share.track');

    // 🛒 Shopping Cart Routes
    Route::get('/cart', [StoreController::class, 'cart'])->name('cart.index');
    Route::post('/add-to-cart', [StoreController::class, 'addToCart'])->name('addToCart');
    Route::post('/cart/update/{id}', [CartController::class, 'update'])->name('cart.update');
    Route::get('/cart/remove/{id}', [CartController::class, 'remove'])->name('cart.remove');
    Route::get('/cart/count', [StoreController::class, 'cartCount'])->name('cartCount');
    Route::post('/clear-cart', [StoreController::class, 'clearCart'])->name('clearCart');
    Route::get('/cart/clear', [CartController::class, 'clear'])->name('cart.clear');
    
    // Repeated, conflicting route names
    Route::get('/cart/remove/{id}', [CartController::class, 'remove'])->name('cart.remove');
    Route::get('/cart/remove/{id}', [CartController::class, 'remove'])->name('removeFromCart');

    // 🧾 Checkout Routes
    Route::get('/checkout', [CheckoutController::class, 'checkout'])->name('checkout');
    Route::post('/checkout/process', [CheckoutController::class, 'process'])->name('checkout.process');
    
    // 📦 Shipping
    Route::post('/shipping/store', [ShippingController::class, 'store'])->name('shipping.store')->middleware('auth');
            Route::get('/login', [LoginController::class, 'showLoginForm'])->name('login');
  
    // 🔐 Authentication
Route::middleware(['auth'])->group(function () {
    Route::get('/user/orders', [OrderController::class, 'index'])->name('user.orders');
});
Route::middleware(['auth'])->prefix('user')->name('user.')->group(function () {
    Route::get('/affiliate-program', [AffiliateClickController::class, 'index'])->name('affiliate.links');
});

// ðŸ”¹ General Site Routes
Route::controller(SiteController::class)->group(function () {
    Route::get('/contact', 'contact')->name('contact');
    Route::post('/contact', 'contactSubmit');
    Route::get('/change/{lang?}', 'changeLanguage')->name('lang');
    Route::post('subscriber', 'subscriberStore')->name('subscribe');
    Route::get('cookie-policy', 'cookiePolicy')->name('cookie.policy');
    Route::get('/cookie/accept', 'cookieAccept')->name('cookie.accept');
    Route::post('/check/referral', 'CheckUsername')->name('check.referral');
    Route::get('plan', 'plan')->name('plan');
    Route::get('/store', [StoreController::class, 'index'])->name('store');

    Route::get('blog', 'blog')->name('blog');
    Route::get('blog/{slug}', 'blogDetails')->name('blog.details');
    Route::get('policy/{slug}', 'policyPages')->name('policy.pages');
    Route::get('placeholder-image/{size}', 'placeholderImage')->name('placeholder.image');
    Route::get('maintenance-mode','maintenance')->withoutMiddleware('maintenance')->name('maintenance');
    Route::get('/{slug}', 'pages')->name('pages');
    Route::get('/', 'index')->name('home');
    Route::get('/cron', [CronController::class, 'index'])->name('cron');
});
